#[repr(u8)]pub enum Soscerr {
DISABLED_OR_NO_ERROR = 0,
ENABLED_AND_ERROR = 1,
}Variants
DISABLED_OR_NO_ERROR = 0
SOSC Clock Monitor is disabled or has not detected an error
ENABLED_AND_ERROR = 1
SOSC Clock Monitor is enabled and detected an error
Implementations